@@ -1,7 +1,8 @@
 voltcol <-
   function(z,zmin=min(z),zmax=max(z),col=NULL,ncolor=25){
     if(is.null(col[1])){
-      col <- colorRampPalette(c("blueviolet","blue","cyan","green","yellow","orange","red"))(ncolor)
+      #col <- colorRampPalette(c("blueviolet","blue","cyan","green","yellow","orange","red"))(ncolor)
+      col <- colorRampPalette(c("darkblue", rainbow(12)[c(9,8,7,5,3,2,1)], "darkred"))(ncolor)
     } else {
       col <- colorRampPalette(col)(ncolor)
     }
